@@ -5,13 +5,15 @@ import json as _json
 import random as _random
 import string as _string
 
-from ._utf_8 import utf8_coding as _utf8_coding
 import physicsLab._fileGlobals as _fileGlobals
 from physicsLab.electricity.element import crt_Element
 
 ### define ###
 
+# 是否已经有存档被打开或创建
 _ifndef_open_Experiment = False
+# 打印write_Experiment的信息时是否使用彩色字
+_printColor = True
 
 def print_Elements():
     print(_fileGlobals.Elements)
@@ -44,6 +46,27 @@ def old_open_Experiment(file: str) -> None:
         except:
             raise RuntimeError('Data errors in the file')
 
+# 将import了physicsLab的文件的第一行添加上 #coding=utf-8
+def _utf8_coding(func):
+    def result(string: str) -> None:
+        try: # 在cmd或者shell上无法执行该功能
+            import sys
+            s = ''
+            with open(sys.argv[0], encoding='utf-8') as f:
+                s = f.read()
+            if not s.replace('\n', '').startswith('#coding=utf-8'):
+                with open(sys.argv[0], 'w', encoding='utf-8') as f:
+                    if s.startswith('\n'):
+                        f.write(f'#coding=utf-8{s}')
+                    else:
+                        f.write(f'#coding=utf-8\n{s}')
+        except FileNotFoundError:
+            # 在cmd或IDLE上运行时会关闭打印彩字功能
+            global _printColor
+            _printColor = False
+        func(string)
+    return result
+
 # 打开一个指定的sav文件（支持输入本地实验的名字或sav文件名）
 @_utf8_coding
 def open_Experiment(file : str) -> None:
@@ -137,7 +160,10 @@ def write_Experiment() -> None:
             experiments.pop(0)
     with open(f'{_fileGlobals.savName[:len(_fileGlobals.savName) - 4:]}_rollBack_sav.txt', 'w', encoding='utf-8') as f:
         f.write(_json.dumps(experiments, indent=2, ensure_ascii=False))
-    print(f'\033[32mSuccessfully compiled! {_fileGlobals.Elements.__len__()} elements, {_fileGlobals.Wires.__len__()} wires.\033[39m')
+    if _printColor:
+        print(f'\033[32mSuccessfully compiled! {_fileGlobals.Elements.__len__()} elements, {_fileGlobals.Wires.__len__()} wires.\033[39m')
+    else:
+        print(f'Successfully compiled! {_fileGlobals.Elements.__len__()} elements, {_fileGlobals.Wires.__len__()} wires.')
 
 # 读取sav文件已有的原件与导线
 def read_Experiment() -> None:
